/**
 *******************************************************************************
 * @file  hwos_hwfnc.h
 * @brief Hardware function control program for R-IN32M3
 * 
 * @note 
 * Copyright (C) 2011-2013 Renesas Electronics Corporation 
 * Copyright (C) 2011-2013 Renesas Micro Systems Co., Ltd. 
 * 
 * @par
 *  This is a sample program. 
 *  Renesas Electronics assumes no responsibility for any losses incurred. 
 * 
 *******************************************************************************
 */

#ifndef HWOS_HWFNC_H__
#define HWOS_HWFNC_H__

/*============================================================================*/
/* I N C L U D E                                                              */
/*============================================================================*/
#include "RIN32M3.h"
#include "kernel.h"

/*============================================================================*/
/* D E F I N E                                                                */
/*============================================================================*/
/* HWRTOS System call */
#define TSFNC_ext_tsk					0x4000
#define TSFNC_sta_tsk					0x4001
#define TSFNC_ter_tsk					0x4013
#define TSFNC_chg_pri					0x400e
#define TSFNC_cre_flg					0x4002
#define TSFNC_del_flg					0x4003
#define TSFNC_wai_flg					0x4009
#define TSFNC_pol_flg					0x400a
#define TSFNC_set_flg					0x400b
#define TSFNC_clr_flg					0x400d
#define TSFNC_cre_sem					0x4004
#define TSFNC_del_sem					0x4005
#define TSFNC_wai_sem					0x4006
#define TSFNC_sig_sem					0x4007
#define TSFNC_cre_mbx					0x401a
#define TSFNC_del_mbx					0x401b
#define TSFNC_snd_mbx					0x401c
#define TSFNC_rcv_mbx					0x401d
#define TSFNC_loc_cpu					0x400f
#define TSFNC_unl_cpu					0x4010
#define TSFNC_dis_dsp					0x4011
#define TSFNC_ena_dsp					0x4012
#define TSFNC_get_tid					0x4019
#define TSFNC_rot_rdq					0x401e
#define TSFNC_rel_wai					0x4014
#define TSFNC_tslp_tsk					0x4015
#define TSFNC_wup_tsk					0x4016
#define TSFNC_set_tim					0x4017
#define TSFNC_get_tim					0x4018
#define TSFNC_soft_isr					0x401f

/* HWRTOS Error codes */
#define RTOS_E_OK						1L				/* Normal completion								*/
#define RTOS_E_ALREADY_PRIORITY			0x0002L			/* The priority value is already specified			*/
#define RTOS_E_POL_OK_EVENT				0x0003L			/* |[(Cxg)							*/
#define RTOS_E_POL_OK_NO_EVENT			0x0004L			/* |[(Cxg)						*/
#define RTOS_E_INVCAL					0xFF80L			/* Invalid System call								*/
#define RTOS_E_IDLE						0xFF81L			/* the task is in the IDLE state					*/
#define RTOS_E_ALREADY_RUN				0xFF82L			/* the task has already been in RUN state			*/
#define RTOS_E_ENBL						0xFF83L			/* ENABLEɂȂĂ							*/
#define RTOS_E_ID						0xFF84L			/* Invalid ID										*/
#define RTOS_E_NOEXS					0xFF85L			/* Non-existent ogject								*/
#define RTOS_E_TMOUT					0xFF86L			/* Timeout											*/
#define RTOS_E_MUTEX					0xFF87L			/* mutextɂwai_sem^XNƈႤ			*/
#define RTOS_E_STOP						0xFF88L			/* the task is in the STOP state					*/
#define RTOS_E_ISR						0xFF8AL			/* ISRI悤Ƃ							*/
#define RTOS_E_OWN_TASK					0xFF89L			/* the task try to terminate itself					*/
#define RTOS_E_WUP_QUE_IN				0xFF8BL			/* The task is not in the Wait state, 				
														   the wakeup request for the task is queued.		*/
#define RTOS_E_QOVR						0xFF8CL			/* Overflow of wakeup request count					*/
#define RTOS_E_WUP_TASK					0xFF8DL			/* TSFNC_wup_tskɂwaitB					*/
#define RTOS_E_STOP_IDLE				0xFF8EL			/* The specified task is in the STOP state or IDLE state.*/
#define RTOS_E_COUNTER_LARGE			0xFF8FL			/* Z}tHJE^̏lől傫		*/
#define RTOS_E_MBOX_FULL				0xFF8FL			/* [{bNXt								*/
#define RTOS_E_RLWAI					0xFF90L			/* The task is released from waiting with rel_wai	*/
#define RTOS_E_NOT_WAIT					0xFF91L			/* WaitԂł͂Ȃ								*/
#define RTOS_E_INVPRI					0xFF91L			/* wvCIeBs							*/
#define RTOS_E_DLT						0xFF92L			/* ҂IuWFNg̍폜							*/
#define RTOS_E_DLT_SEM					0xFF93L			/* del_semɂEVENTe[u폜ꂽ			*/
#define RTOS_E_DLT_MBX					0xFF94L			/* del_mbxɂ胁[{bNX폜ꂽ			*/

/*============================================================================*/
/* F U N C T I O N   P R O T O T Y P E                                        */
/*============================================================================*/
// ====== Execute systemcall (SVcall) ======
#if defined ( __CC_ARM )
// ------ RealView Compiler ------
void __svc(0) hwos_exec_systemcall(volatile SYSCALL_PARAM *syscall_param);
#elif defined ( __GNUC__ )
// ------ GNU Compiler ------
#define hwos_exec_systemcall(value) \
  __asm__ __volatile__ ("mov r0, %0 \n\t" \
                        "svc 0      \n\t" \
                        : : "r" (value) : "r0");
#elif defined ( __ICCARM__ )
// ------ IAR Compiler ------
#pragma swi_number=0x00
__swi void hwos_exec_systemcall(volatile SYSCALL_PARAM *syscall_param);
#endif

// ====== Buffer allocator ======
UINT hwfnc_longbuffer_get(UINT par);
UINT hwfnc_shortbuffer_get(UINT len);
UINT hwfnc_buffer_release(UINT top);
UINT hwfnc_buffer_return(UINT top, UINT addr);
UINT hwfnc_longbuffer_link(UINT src, UINT *p_sta);

// ====== HeaderEnDec ======
UINT hwfnc_gbe_enc(UINT src, UINT dst, UINT *excp);
UINT hwfnc_gbe_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_snap_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_ip4_enc(UINT src, UINT dst, UINT *excp);
UINT hwfnc_ip4_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_ip6_enc(UINT src, UINT dst, UINT *excp);
UINT hwfnc_ip6_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_tcp_enc(UINT src, UINT dst, UINT *excp);
UINT hwfnc_tcp_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_udp_enc(UINT src, UINT dst, UINT *excp);
UINT hwfnc_udp_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_arp_enc(UINT src, UINT dst, UINT *excp);
UINT hwfnc_arp_dec(UINT src, UINT dst, UINT *excp);
UINT hwfnc_dsc_trns(UINT src, UINT dst, UINT *excp);
UINT hwfnc_dmt(UINT src, UINT dst, UINT bytes, UINT *excp);
UINT hwfnc_dmr(UINT src, UINT dst, UINT bytes, UINT *excp);

// ====== DMAC ======
// --- MACDMA ---
UINT hwfnc_macdma_tx_start(UINT dsc, UINT llsn);
UINT hwfnc_macdma_rx_enable(UINT llsn);
UINT hwfnc_macdma_rx_disable(UINT flg);
UINT hwfnc_macdma_rx_control(UINT msk);
UINT hwfnc_macdma_tx_errstat(void);
UINT hwfnc_macdma_rx_errstat(void);

// --- INTBUFF DMA ---
/* Internal Buffer */
UINT hwfnc_intbuff_dma_start1(UINT dst, UINT src, UINT bytes, UINT llsn);
UINT hwfnc_intbuff_dma_start2(UINT ddsc, UINT sdsc, UINT llsn);

#endif	// HWOS_HWFNC_H__
